@@ -10,11 +10,7 @@
 #include "gdk.h"
 #include "gdk_private.h"
 #include "gdk_calc_private.h"
-#if defined(_MSC_VER) && defined(__INTEL_COMPILER)
-#include <mathimf.h>
-#else
 #include <math.h>
-#endif
 
 /* grouped aggregates
  *
@@ -1994,8 +1990,6 @@ BATcalcavg(BAT *b, BAT *s, dbl *avg, BUN *vals)
 				if (cand == candend)			\
 					break;				\
 				i = *cand++ - b->hseqbase;		\
-				if (i >= end)				\
-					break;				\
 			} else {					\
 				i = start++;				\
 				if (i == end)				\
@@ -2007,7 +2001,7 @@ BATcalcavg(BAT *b, BAT *s, dbl *avg, BUN *vals)
 					gid = gids[i] - min;		\
 				else					\
 					gid = (oid) i;			\
-				if (!skip_nils || vals[i] != TYPE##_nil) { \
+				if (vals[i] != TYPE##_nil) {		\
 					cnts[gid]++;			\
 				}					\
 			}						\
@@ -2047,7 +2041,7 @@ BATgroupcount(BAT *b, BAT *g, BAT *e, BAT *s, int tp, int skip_nils, int abort_o
 	}
 
 	if (BATcount(b) == 0 || ngrp == 0) {
-		/* trivial: no products, so return bat aligned with g
+		/* trivial: no counts, so return bat aligned with g
 		 * with zero in the tail */
 		lng zero = 0;
 		return BATconstant(ngrp == 0 ? 0 : min, TYPE_lng, &zero, ngrp, TRANSIENT);
@@ -2064,62 +2058,89 @@ BATgroupcount(BAT *b, BAT *g, BAT *e, BAT *s, int tp, int skip_nils, int abort_o
 	else
 		gids = (const oid *) Tloc(g, start);
 
-	t = b->ttype;
-	nil = ATOMnilptr(t);
-	atomcmp = ATOMcompare(t);
-	t = ATOMbasetype(t);
-	switch (t) {
-	case TYPE_bte:
-		AGGR_COUNT(bte);
-		break;
-	case TYPE_sht:
-		AGGR_COUNT(sht);
-		break;
-	case TYPE_int:
-		AGGR_COUNT(int);
-		break;
-	case TYPE_lng:
-		AGGR_COUNT(lng);
-		break;
-#ifdef HAVE_HGE
-	case TYPE_hge:
-		AGGR_COUNT(hge);
-		break;
-#endif
-	case TYPE_flt:
-		AGGR_COUNT(flt);
-		break;
-	case TYPE_dbl:
-		AGGR_COUNT(dbl);
-		break;
-	default:
-		bi = bat_iterator(b);
-
-		for (;;) {
-			if (cand) {
-				if (cand == candend)
-					break;
-				i = *cand++ - b->hseqbase;
-				if (i >= end)
-					break;
+	if (!skip_nils || b->tnonil) {
+		/* if nils are nothing special, or if there are no
+		 * nils, we don't need to look at the values at all */
+		if (cand) {
+			if (gids) {
+				while (cand < candend) {
+					i = *cand++ - b->hseqbase;
+					if (gids[i] >= min && gids[i] <= max)
+						cnts[gids[i] - min]++;
+				}
 			} else {
-				i = start++;
-				if (i == end)
-					break;
-			}
-			if (gids == NULL ||
-			    (gids[i] >= min && gids[i] <= max)) {
-				if (gids)
-					gid = gids[i] - min;
-				else
-					gid = (oid) i;
-				if (!skip_nils ||
-				    (*atomcmp)(BUNtail(bi, i), nil) != 0) {
-					cnts[gid]++;
+				while (cand < candend) {
+					i = *cand++ - b->hseqbase;
+					cnts[i] = 1;
 				}
 			}
+		} else {
+			if (gids) {
+				for (i = start; i < end; i++) {
+					if (gids[i] >= min && gids[i] <= max)
+						cnts[gids[i] - min]++;
+				}
+			} else {
+				for (i = start; i < end; i++)
+					cnts[i] = 1;
+			}
+		}
+	} else {
+		t = b->ttype;
+		nil = ATOMnilptr(t);
+		atomcmp = ATOMcompare(t);
+		t = ATOMbasetype(t);
+
+		switch (t) {
+		case TYPE_bte:
+			AGGR_COUNT(bte);
+			break;
+		case TYPE_sht:
+			AGGR_COUNT(sht);
+			break;
+		case TYPE_int:
+			AGGR_COUNT(int);
+			break;
+		case TYPE_lng:
+			AGGR_COUNT(lng);
+			break;
+#ifdef HAVE_HGE
+		case TYPE_hge:
+			AGGR_COUNT(hge);
+			break;
+#endif
+		case TYPE_flt:
+			AGGR_COUNT(flt);
+			break;
+		case TYPE_dbl:
+			AGGR_COUNT(dbl);
+			break;
+		default:
+			bi = bat_iterator(b);
+
+			for (;;) {
+				if (cand) {
+					if (cand == candend)
+						break;
+					i = *cand++ - b->hseqbase;
+				} else {
+					i = start++;
+					if (i == end)
+						break;
+				}
+				if (gids == NULL ||
+				    (gids[i] >= min && gids[i] <= max)) {
+					if (gids)
+						gid = gids[i] - min;
+					else
+						gid = (oid) i;
+					if ((*atomcmp)(BUNtail(bi, i), nil) != 0) {
+						cnts[gid]++;
+					}
+				}
+			}
+			break;
 		}
-		break;
 	}
 	BATsetcount(bn, ngrp);
 	bn->tkey = BATcount(bn) <= 1;
@@ -2804,7 +2825,8 @@ BATgroupquantile(BAT *b, BAT *g, BAT *e, BAT *s, int tp, double quantile,
 				nils++;
 			} else {
 				/* round *down* to nearest integer */
-				qindex = r + p - (BUN) (p + 0.5 - (p - r - 1) * quantile);
+				double f = (p - r - 1) * quantile;
+				qindex = r + p - (BUN) (p + 0.5 - f);
 				/* be a little paranoid about the index */
 				assert(qindex >= r && qindex <  p);
 				v = BUNtail(bi, qindex);
@@ -2859,11 +2881,13 @@ BATgroupquantile(BAT *b, BAT *g, BAT *e, BAT *s, int tp, double quantile,
 			v = nil;
 			nils++;
 		} else {
+			double f;
 			bi = bat_iterator(b);
 			/* round (p-r-1)*quantile *down* to nearest
 			 * integer (i.e., 1.49 and 1.5 are rounded to
 			 * 1, 1.51 is rounded to 2) */
-			index = r + p - (BUN) (p + 0.5 - (p - r - 1) * quantile);
+			f = (p - r - 1) * quantile;
+			index = r + p - (BUN) (p + 0.5 - f);
 			if (ords)
 				index = ords[index] - b->hseqbase;
 			else
