@@ -58,6 +58,7 @@
 #include "gdk_private.h"
 #include "gdk_logger.h"
 #include "mutils.h"
+
 #include <string.h>
 
 /*
@@ -1329,6 +1330,7 @@ bm_subcommit(logger *lg, BAT *list_bid, BAT *list_nme, BAT *catalog_bid, BAT *ca
 		}
 		bids = logbat_new(TYPE_int, BATcount(tids), PERSISTENT);
 		nmes = logbat_new(TYPE_str, BATcount(tids), PERSISTENT);
+
 		if (bids == NULL || nmes == NULL) {
 			logbat_destroy(tids);
 			logbat_destroy(bids);
@@ -1336,6 +1338,7 @@ bm_subcommit(logger *lg, BAT *list_bid, BAT *list_nme, BAT *catalog_bid, BAT *ca
 			GDKfree(n);
 			return GDK_FAIL;
 		}
+
 		if (BATappend(bids, catalog_bid, tids, TRUE) != GDK_SUCCEED ||
 		    BATappend(nmes, catalog_nme, tids, TRUE) != GDK_SUCCEED) {
 			logbat_destroy(tids);
@@ -1534,13 +1537,15 @@ logger_load(int debug, const char *fn, char filename[PATHLENGTH], logger *lg)
 			goto error;
 		}
 		if (fflush(fp) < 0 ||
+		    (!(GDKdebug & NOSYNCMASK)
 #if defined(_MSC_VER)
-		    _commit(_fileno(fp)) < 0 ||
+		     && _commit(_fileno(fp)) < 0
 #elif defined(HAVE_FDATASYNC)
-		    fdatasync(fileno(fp)) < 0 ||
+		     && fdatasync(fileno(fp)) < 0
 #elif defined(HAVE_FSYNC)
-		    fsync(fileno(fp)) < 0 ||
+		     && fsync(fileno(fp)) < 0
 #endif
+			    ) ||
 		    fclose(fp) < 0) {
 			unlink(filename);
 			GDKerror("logger_load: closing log file %s failed",
@@ -2073,14 +2078,15 @@ logger_exit(logger *lg)
 		}
 
 		if (fflush(fp) < 0 ||
-#if defined(NATIVE_WIN32)
-		    _commit(_fileno(fp)) < 0
+		    (!(GDKdebug & NOSYNCMASK)
+#if defined(WIN32)
+		     && _commit(_fileno(fp)) < 0
 #elif defined(HAVE_FDATASYNC)
-		    fdatasync(fileno(fp)) < 0
+		     && fdatasync(fileno(fp)) < 0
 #elif defined(HAVE_FSYNC)
-		    fsync(fileno(fp)) < 0
+		     && fsync(fileno(fp)) < 0
 #endif
-			) {
+			    )) {
 			(void) fclose(fp);
 			fprintf(stderr, "!ERROR: logger_exit: flush of %s failed\n",
 				filename);
@@ -2615,7 +2621,7 @@ log_tend(logger *lg)
 	if (res != GDK_SUCCEED ||
 	    log_write_format(lg, &l) != GDK_SUCCEED ||
 	    mnstr_flush(lg->log) ||
-	    mnstr_fsync(lg->log) ||
+	    (!(GDKdebug & NOSYNCMASK) && mnstr_fsync(lg->log)) ||
 	    pre_allocate(lg) != GDK_SUCCEED) {
 		fprintf(stderr, "!ERROR: log_tend: write failed\n");
 		return GDK_FAIL;
@@ -2656,7 +2662,7 @@ log_sequence_(logger *lg, int seq, lng val, int flush)
 	if (log_write_format(lg, &l) != GDK_SUCCEED ||
 	    !mnstr_writeLng(lg->log, val) ||
 	    (flush && mnstr_flush(lg->log)) ||
-	    (flush && mnstr_fsync(lg->log)) ||
+	    (flush && !(GDKdebug & NOSYNCMASK) && mnstr_fsync(lg->log)) ||
 	    pre_allocate(lg) != GDK_SUCCEED) {
 		fprintf(stderr, "!ERROR: log_sequence_: write failed\n");
 		return GDK_FAIL;
@@ -2683,7 +2689,7 @@ log_sequence_nrs(logger *lg)
 	}
 	if (ok != GDK_SUCCEED ||
 	    mnstr_flush(lg->log) ||
-	    mnstr_fsync(lg->log)) {
+	    (!(GDKdebug & NOSYNCMASK) && mnstr_fsync(lg->log))) {
 		fprintf(stderr, "!ERROR: log_sequence_nrs: write failed\n");
 		return GDK_FAIL;
 	}
