@@ -428,7 +428,7 @@ GDKsave(int farmid, const char *nme, const char *ext, void *buf, size_t size, st
 	IODEBUG fprintf(stderr, "#GDKsave: name=%s, ext=%s, mode %d, dosync=%d\n", nme, ext ? ext : "", (int) mode, dosync);
 
 	if (mode == STORE_MMAP) {
-		if (dosync && size && MT_msync(buf, size) < 0)
+		if (dosync && size && !(GDKdebug & NOSYNCMASK) && MT_msync(buf, size) < 0)
 			err = -1;
 		if (err)
 			GDKsyserror("GDKsave: error on: name=%s, ext=%s, "
@@ -470,15 +470,13 @@ GDKsave(int farmid, const char *nme, const char *ext, void *buf, size_t size, st
 						(unsigned) MIN(1 << 30, size),
 						ret);
 			}
-			if (dosync && !(GDKdebug & FORCEMITOMASK) &&
+			if (dosync && !(GDKdebug & NOSYNCMASK)
 #if defined(NATIVE_WIN32)
-			    _commit(fd) < 0
+			    && _commit(fd) < 0
 #elif defined(HAVE_FDATASYNC)
-			    fdatasync(fd) < 0
+			    && fdatasync(fd) < 0
 #elif defined(HAVE_FSYNC)
-			    fsync(fd) < 0
-#else
-			    0
+			    && fsync(fd) < 0
 #endif
 				) {
 				GDKsyserror("GDKsave: error on: name=%s, "
@@ -629,7 +627,6 @@ DESCload(int i)
 		return NULL;
 	}
 	b->ttype = tt;
-	b->thash = NULL;
 
 	/* reconstruct mode from BBP status (BATmode doesn't flush
 	 * descriptor, so loaded mode may be stale) */
@@ -683,8 +680,7 @@ BATmsync(BAT *b)
 {
 	assert(!GDKinmemory());
 
-	/* we don't sync views */
-	if (isVIEW(b))
+	if (isVIEW(b) || (GDKdebug & NOSYNCMASK))
 		return;
 	/* we don't sync transients */
 	if (b->theap.farmid != 0 ||
@@ -843,6 +839,9 @@ BATload_intern(bat bid, int lock)
 		}
 		if (ATOMstorage(b->ttype) == TYPE_str) {
 			strCleanHash(b->tvheap, FALSE);	/* ensure consistency */
+		} else {
+			HEAP_recover(b->tvheap, (const var_t *) Tloc(b, 0),
+				     BATcount(b));
 		}
 	}
 
