@@ -9,10 +9,10 @@
 #ifndef MAL_BACKEND_H
 #define MAL_BACKEND_H
 
-#include <mal.h>
-#include <mal_client.h>
-#include <sql_mvc.h>
-#include <sql_qc.h>
+#include "mal.h"
+#include "mal_client.h"
+#include "sql_mvc.h"
+#include "sql_qc.h"
 
 /*
  * The back-end structure collects the information needed to support
