@@ -24,17 +24,16 @@
 #include "sql_env.h"
 #include "sql_mvc.h"
 #include "sql_user.h"
-#include <sql_optimizer.h>
-#include <sql_datetime.h>
-#include <rel_optimizer.h>
-#include <rel_partition.h>
-#include <rel_distribute.h>
-#include <rel_select.h>
-#include <rel_rel.h>
-#include <rel_exp.h>
-#include <rel_dump.h>
-#include <rel_bin.h>
-#include <mtime.h>
+#include "sql_optimizer.h"
+#include "sql_datetime.h"
+#include "rel_optimizer.h"
+#include "rel_partition.h"
+#include "rel_distribute.h"
+#include "rel_select.h"
+#include "rel_rel.h"
+#include "rel_exp.h"
+#include "rel_dump.h"
+#include "mtime.h"
 #include "optimizer.h"
 #include "opt_inline.h"
 #include <unistd.h>
