@@ -350,8 +350,9 @@ subtype_cmp(sql_subtype *t1, sql_subtype *t2)
 {
 	if (!t1->type || !t2->type)
 		return -1;
+
 	if ( !(t1->type->eclass == t2->type->eclass && 
-	       EC_INTERVAL(t1->type->eclass)) &&
+	      (EC_INTERVAL(t1->type->eclass) || t1->type->eclass == EC_NUM)) &&
 	      (t1->digits != t2->digits || 
 	      (!(t1->type->eclass == t2->type->eclass && 
 	       t1->type->eclass == EC_FLT) &&
@@ -643,25 +644,43 @@ sql_dup_subfunc(sql_allocator *sa, sql_func *f, list *ops, sql_subtype *member)
 	} else if (IS_FUNC(f) || IS_UNION(f) || IS_ANALYTIC(f)) { /* not needed for PROC */
 		unsigned int mscale = 0, mdigits = 0;
 
-		if (ops) for (tn = ops->h; tn; tn = tn->next) {
-			sql_subtype *a = tn->data;
-
-			/* same scale as the input */
-			if (a && a->scale > mscale)
+		if (ops) {
+			if (ops->h && ops->h->data && f->imp &&
+			    strcmp(f->imp, "round") == 0) {
+				/* special case for round(): result is
+				 * same type as first argument */
+				sql_subtype *a = ops->h->data;
 				mscale = a->scale;
-			if (a && f->fix_scale == INOUT)
 				mdigits = a->digits;
+			} else {
+				for (tn = ops->h; tn; tn = tn->next) {
+					sql_subtype *a = tn->data;
+
+					/* same scale as the input */
+					if (a && a->scale > mscale)
+						mscale = a->scale;
+					if (a && f->fix_scale == INOUT)
+						mdigits = a->digits;
+				}
+			}
 		}
 
 		if (!member) {
 			node *m;
+			sql_arg *ma = NULL;
 
 			if (ops) for (tn = ops->h, m = f->ops->h; tn; tn = tn->next, m = m->next) {
 				sql_arg *s = m->data;
 
-				if (s->type.type->eclass == EC_ANY) {
+				if (!member && s->type.type->eclass == EC_ANY) {
 					member = tn->data;
-					break;
+					ma = s;
+				}
+				/* largest type */
+				if (member && s->type.type->eclass == EC_ANY &&
+				    s->type.type->localtype > ma->type.type->localtype ) {
+					member = tn->data;
+					ma = s;
 				}
 			}
 		}
@@ -806,6 +825,59 @@ sql_find_func(sql_allocator *sa, sql_schema *s, const char *sqlfname, int nrargs
 	return NULL;
 }
 
+list *
+sql_find_funcs(sql_allocator *sa, sql_schema *s, const char *sqlfname, int nrargs, int type)
+{
+	sql_subfunc *fres;
+	int key = hash_key(sqlfname);
+	sql_hash_e *he;
+	int filt = (type == F_FUNC)?F_FILT:type;
+	list *res = sa_list(sa);
+
+	assert(nrargs);
+	MT_lock_set(&funcs->ht_lock);
+	he = funcs->ht->buckets[key&(funcs->ht->size-1)]; 
+	for (; he; he = he->chain) {
+		sql_func *f = he->value;
+
+		if (f->type != type && f->type != filt) 
+			continue;
+		if ((fres = func_cmp(sa, f, sqlfname, nrargs )) != NULL) 
+			list_append(res, fres);
+	}
+	MT_lock_unset(&funcs->ht_lock);
+	if (s) {
+		node *n;
+
+		if (s->funcs.set) {
+			MT_lock_set(&s->funcs.set->ht_lock);
+			if (s->funcs.set->ht) {
+				he = s->funcs.set->ht->buckets[key&(s->funcs.set->ht->size-1)];
+				for (; he; he = he->chain) {
+					sql_func *f = he->value;
+
+					if (f->type != type && f->type != filt) 
+						continue;
+					if ((fres = func_cmp(sa, f, sqlfname, nrargs )) != NULL)
+						list_append(res, fres);
+				}
+			} else {
+				n = s->funcs.set->h;
+				for (; n; n = n->next) {
+					sql_func *f = n->data;
+
+					if (f->type != type && f->type != filt) 
+						continue;
+					if ((fres = func_cmp(sa, f, sqlfname, nrargs )) != NULL)
+						list_append(res, fres);
+				}
+			}
+			MT_lock_unset(&s->funcs.set->ht_lock);
+		}
+	}
+	return res;
+}
+
 
 /* find function based on first argument */
 sql_subfunc *
@@ -1194,7 +1266,8 @@ sql_create_func_(sql_allocator *sa, const char *name, const char *mod, const cha
 {
 	sql_func *t = SA_ZNEW(sa, sql_func);
 
-	assert(res && ops);
+	if (!ops)
+		ops = sa_list(sa);
 	base_init(sa, &t->base, store_next_oid(), TR_OLD, name);
 	t->imp = sa_strdup(sa, imp);
 	t->mod = sa_strdup(sa, mod);
@@ -1834,6 +1907,10 @@ sqltypeinit( sql_allocator *sa)
 			create_arg(sa, NULL, sql_create_subtype(sa, STR, 0, 0), ARG_IN)), 
 			create_arg(sa, NULL, sql_create_subtype(sa, STR, 0, 0), ARG_IN)), sres, FALSE, F_UNION, SCALE_FIX);
 	f->varres = 1;
+
+	/* sys_update_schemas, sys_update_tables */
+	f = sql_create_func_(sa, "sys_update_schemas", "sql", "update_schemas", NULL, NULL, FALSE, F_PROC, SCALE_NONE);
+	f = sql_create_func_(sa, "sys_update_tables", "sql", "update_tables", NULL, NULL, FALSE, F_PROC, SCALE_NONE);
 }
 
 void
