@@ -6,7 +6,7 @@
  * Copyright 1997 - July 2008 CWI, August 2008 - 2017 MonetDB B.V.
  */
 
-#include <monetdb_config.h>
+#include "monetdb_config.h"
 #include "sql_relation.h"
 #include "rel_exp.h"
 #include "rel_prop.h" /* for prop_copy() */
@@ -1305,6 +1305,19 @@ exp_is_correlation(sql_exp *e, sql_rel *r )
 	return -1;
 }
 
+int
+exp_is_true(mvc *sql, sql_exp *e) 
+{
+	if (e->type == e_atom) {
+		if (e->l) {
+			return atom_is_true(e->l);
+		} else if(sql->emode == m_normal && sql->argc > e->flag && EC_BOOLEAN(exp_subtype(e)->type->eclass)) {
+			return atom_is_true(sql->args[e->flag]);
+		}
+	}
+	return 0;
+}
+
 int
 exp_is_zero(mvc *sql, sql_exp *e) 
 {
