@@ -11,7 +11,7 @@
 
 #include <stdio.h>
 #include <stdarg.h>
-#include <sql_list.h>
+#include "sql_list.h"
 #include "sql_symbol.h"
 
 extern sql_rel *rel_schemas(mvc *sql, symbol *sym);
