@@ -1168,7 +1168,7 @@ table_column_types(sql_allocator *sa, sql_table *t)
 }
 
 static list *
-table_column_names(sql_allocator *sa, sql_table *t)
+table_column_names_and_defaults(sql_allocator *sa, sql_table *t)
 {
 	node *n;
 	list *types = sa_list(sa);
@@ -1176,6 +1176,7 @@ table_column_names(sql_allocator *sa, sql_table *t)
 	if (t->columns.set) for (n = t->columns.set->h; n; n = n->next) {
 		sql_column *c = n->data;
 		append(types, &c->base.name);
+		append(types, c->def);
 	}
 	return types;
 }
@@ -1571,7 +1572,7 @@ copyfromloader(mvc *sql, dlist *qname, symbol *fcall)
 		return NULL;
 	}
 	((sql_subfunc*) import->f)->res = table_column_types(sql->sa, t);
-	((sql_subfunc*) import->f)->colnames = table_column_names(sql->sa, t);
+	((sql_subfunc*) import->f)->colnames = table_column_names_and_defaults(sql->sa, t);
 
 	for (n = t->columns.set->h; n; n = n->next) {
 		sql_column *c = n->data;
