@@ -11,10 +11,10 @@
 
 #include <stdio.h>
 #include <stdarg.h>
-#include <sql_list.h>
+#include "sql_list.h"
 #include "sql_symbol.h"
 #include "sql_mvc.h"
-#include <sql_relation.h>
+#include "sql_relation.h"
 
 extern sql_exp **table_update_array(mvc *sql, sql_table *t);
 extern sql_rel *rel_update(mvc *sql, sql_rel *t, sql_rel *uprel, sql_exp **updates, list *exps);
