@@ -21,7 +21,7 @@
 #include "monetdb_config.h"
 #include "sql_privileges.h"
 #include "sql_semantic.h"
-#include <sql_parser.h>
+#include "sql_parser.h"
 
 #define PRIV_ROLE_ADMIN 0
 
