@@ -9,9 +9,9 @@
 #include "monetdb_config.h"
 #include "bat_storage.h"
 #include "bat_utils.h"
-#include <sql_string.h>
-#include <gdk_atoms.h>
-#include "../../../mal/modules/algebra.h"
+#include "sql_string.h"
+#include "algebra.h"
+#include "gdk_atoms.h"
 
 #define SNAPSHOT_MINSIZE ((BUN) 1024*128)
 
